MultiTypeAdapter class
- Description: 多种数据视图的适配器
- Author: 郭文龙
- Date: 2022/6/29 23:04
- Email: guowenlong20000@sina.com
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
itemViewBinders
↔ List<
ItemViewBinder> -
One to one binding view container
getter/setter pair
-
links
↔ HashMap<
int, Linker> -
One to many binding view container
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getItemBuilder(
BuildContext context, int index, dynamic item) → Widget - Parse the data corresponding to the bound view
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register<
T> (ItemViewBinder< T> binder) → void - Register one to one data and binding view
-
registerOneToMany<
T> (Linker< T> call) → void - Register one to many data and binding view
-
registerUnsupportedViewBinder(
ItemViewBinder unsupportedViewBinder) → void - Register not support data's view
-
setDebugViewBinderEnable(
{bool isEnable = !inProduction, ItemViewBinder? debugViewBinder}) → void - Set debug data and binding view visible
-
toString(
) → String -
A string representation of this object.
inherited
-
unregister<
T> (ItemViewBinder< T> binder) → void - Unregister one to one data and binding view
-
unregisterOneToMany<
T> ({Linker< T> ? call}) → void - Unregister one to many data and binding view
-
unregisterUnsupportedViewBinder(
ItemViewBinder unsupportedViewBinder) → void - Unregister not support data's view
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
newInstance(
Register register) → MultiTypeAdapter
Constants
- inProduction → const bool
-
Returns the boolean value of the environment declaration
name.